==> haskell-authenticate-1.3.4-57-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-HnKhUn2AkjGLV9f3RjDyrW
key: authenticate-1.3.4-HnKhUn2AkjGLV9f3RjDyrW
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
indefinite: False
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: f0c20bc604b57e47b60d14bbca1ce261
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-HnKhUn2AkjGLV9f3RjDyrW
depends:
    aeson-1.2.4.0-CTZGfBqMyO6AGhBfx14U8h
    attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco base-4.10.1.0
    blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski bytestring-0.10.8.2
    case-insensitive-1.2.0.10-GwUFN11YDUS3aWErjHGiBw
    conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U containers-0.5.10.2
    http-conduit-2.2.4-2y4SW0lE28RFQpWflkrdkU
    http-types-0.9.1-BnmUD9RxZRhHekChwpKApV
    network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
    resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo
    tagstream-conduit-0.5.5.3-JjEM4UxLDkk1qdCI0vBrHs
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn
    xml-conduit-1.7.1.2-ClQhMhFhZgP1a5OhxK9AAG
abi-depends: aeson-1.2.4.0-CTZGfBqMyO6AGhBfx14U8h=8c49f5b853f3a7be5ef595f7dce8b68a
             attoparsec-0.13.2.2-ImfqXHsnQ0kLjIvcUXLfco=02dde2665ea78b3a3aa2c59359e39730
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski=ca4639e6cf9a757510daffd0af64d66d
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.10-GwUFN11YDUS3aWErjHGiBw=925191f86667b41dcb51c4650e0bf4fb
             conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U=caeb25cfddba8a8d9ec474fb262978cb
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             http-conduit-2.2.4-2y4SW0lE28RFQpWflkrdkU=41a3be4416b2bc7d568819de2c1f0b1a
             http-types-0.9.1-BnmUD9RxZRhHekChwpKApV=17904082cafa5b41bdd6c56cc1e99042
             network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3=afebcc3944e17103658dd7506cfde008
             resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo=af01948f1b6a617c3a6af518771ef52e
             tagstream-conduit-0.5.5.3-JjEM4UxLDkk1qdCI0vBrHs=d92417229e01bc92826ad2414e2eff9d
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unordered-containers-0.2.9.0-GlwZSbNHLsw5b3PDCuUikn=e523ad11a5c5a0977b92d6afb6220c8b
             xml-conduit-1.7.1.2-ClQhMhFhZgP1a5OhxK9AAG=7df4005161433cc67833c1d2e5f8ef65
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.4-69-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.4
id: authenticate-1.3.4-Kgy13U1oars2jRDaVdIKXY
key: authenticate-1.3.4-Kgy13U1oars2jRDaVdIKXY
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
indefinite: False
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: 13e8d628a42a383560901476e4889acf
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/authenticate-1.3.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/authenticate-1.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/authenticate-1.3.4
hs-libraries: HSauthenticate-1.3.4-Kgy13U1oars2jRDaVdIKXY
depends:
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj base-4.10.1.0
    blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski bytestring-0.10.8.2
    case-insensitive-1.2.0.10-8WNvhsdLPpR42Fom6BKSoi
    conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U containers-0.5.10.2
    http-conduit-2.2.4-9zgIPFRrvm5CbQW8OaICXd
    http-types-0.9.1-HaxgCYZbcak8u9TfZKlScE
    network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
    resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo
    tagstream-conduit-0.5.5.3-KLiWOm6zSgDCeunOZ58VmY
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj transformers-0.5.2.0
    unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz
    xml-conduit-1.7.1.2-JZcJsNgBM7i99w4axZrDfn
abi-depends: aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             blaze-builder-0.4.0.2-LgKKusoD6S36d41ySZ5Ski=ca4639e6cf9a757510daffd0af64d66d
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             case-insensitive-1.2.0.10-8WNvhsdLPpR42Fom6BKSoi=0b97b6fa7495f4ef25b16b185d488b0f
             conduit-1.2.13-CDuZ28lGSu78a4713mMJ0U=caeb25cfddba8a8d9ec474fb262978cb
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             http-conduit-2.2.4-9zgIPFRrvm5CbQW8OaICXd=2326188685fb75cce9c71e3e42ed488e
             http-types-0.9.1-HaxgCYZbcak8u9TfZKlScE=33f0582260438c22e48ef849288f31d3
             network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3=afebcc3944e17103658dd7506cfde008
             resourcet-1.1.11-mPI1cqUz3aG4xWjbFZjoo=af01948f1b6a617c3a6af518771ef52e
             tagstream-conduit-0.5.5.3-KLiWOm6zSgDCeunOZ58VmY=c7f432998f1350671e4c81402f7b4563
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             unordered-containers-0.2.9.0-BDwE3H9gLbqBuONTkERyOz=9d795026e0df763f1ffeaf92b7adcdda
             xml-conduit-1.7.1.2-JZcJsNgBM7i99w4axZrDfn=8e0df37b4a40c66a454e8c3086f1b9cf
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
